@@ -23,7 +23,7 @@
 #include "job.h"
 #include "job_p.h"
 #include "account.h"
-
+#include "networkaccessmanagerfactory_p.h"
 #include "../debug.h"
 #include "authjob.h"
 
@@ -46,8 +46,8 @@ void Job::Private::init()
 {
     QTimer::singleShot(0, q, [this]() { _k_doStart(); });
 
-    accessManager = new KIO::Integration::AccessManager(q);
-    connect(accessManager, &KIO::AccessManager::finished,
+    accessManager = NetworkAccessManagerFactory::instance()->networkAccessManager(q);
+    connect(accessManager, &QNetworkAccessManager::finished,
             q, [this](QNetworkReply *reply) { _k_replyReceived(reply); });
 
     dispatchTimer = new QTimer(q);
@@ -120,9 +120,9 @@ void Job::Private::_k_replyReceived(QNetworkReply* reply)
 
         case KGAPI2::TemporarilyMoved: {  /** << Temporarily moved - Google provides a new URL where to send the request */
             qCDebug(KGAPIDebug) << "Google says: Temporarily moved to " << reply->header(QNetworkRequest::LocationHeader).toUrl();
-            QNetworkRequest request = reply->request();
+            QNetworkRequest request = currentRequest.request;
             request.setUrl(reply->header(QNetworkRequest::LocationHeader).toUrl());
-            q->enqueueRequest(request);
+            q->enqueueRequest(request, currentRequest.rawData, currentRequest.contentType);
             return;
         }
 
