@@ -1,5 +1,5 @@
 /*
-    Copyright 2012  Dan Vratil <dan@progdan.cz>
+    Copyright (C) 2012 - 2018  Daniel Vrátil <dvratil@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -23,7 +23,9 @@
 #include "../../debug.h"
 
 #include <QTcpServer>
+#include <QTcpSocket>
 #include <QAbstractSocket>
+#include <QUrlQuery>
 
 using namespace KGAPI2;
 
@@ -32,7 +34,14 @@ AuthWidget::AuthWidget(QWidget* parent):
     QWidget(parent),
     d(new AuthWidgetPrivate(this))
 {
+    d->setupUi();
+}
 
+AuthWidget::AuthWidget(AuthWidgetPrivate *dptr, QWidget *parent)
+    : QWidget(parent)
+    , d(dptr)
+{
+    d->setupUi();
 }
 
 AuthWidget::~AuthWidget()
@@ -102,7 +111,7 @@ void AuthWidget::authenticate()
     }
 
     d->server = new QTcpServer(this);
-    if (!d->server->listen(QHostAddress::LocalHost)) {
+    if (!d->server->listen(QHostAddress::LocalHost, d->serverPort)) {
         Q_EMIT error(InvalidAccount, tr("Could not start oauth http server"));
         return;
     }
@@ -119,20 +128,16 @@ void AuthWidget::authenticate()
     });
 
     QUrl url(QStringLiteral("https://accounts.google.com/o/oauth2/auth"));
-    url.addQueryItem(QStringLiteral("client_id"), d->apiKey);
-    url.addQueryItem(QStringLiteral("redirect_uri"), QStringLiteral("http://127.0.0.1:%1").arg(d->serverPort));
-    url.addQueryItem(QStringLiteral("scope"), scopes.join(QStringLiteral(" ")));
-    url.addQueryItem(QStringLiteral("response_type"), QStringLiteral("code"));
+    QUrlQuery query(url);
+    query.addQueryItem(QStringLiteral("client_id"), d->apiKey);
+    query.addQueryItem(QStringLiteral("redirect_uri"), QStringLiteral("http://127.0.0.1:%1").arg(d->serverPort));
+    query.addQueryItem(QStringLiteral("scope"), scopes.join(QStringLiteral(" ")));
+    query.addQueryItem(QStringLiteral("response_type"), QStringLiteral("code"));
+    url.setQuery(query);
 
     qCDebug(KGAPIRaw) << "Requesting new token:" << url;
 
-    d->sslIndicator->setVisible(true);
-    d->urlEdit->setVisible(true);
-    d->webview->setVisible(true);
-    if (d->showProgressBar) {
-        d->progressbar->setVisible(true);
-    }
-    d->webview->setUrl(url);
+    d->setVisible(true);
+    d->setUrl(url);
     d->setProgress(AuthWidget::UserLogin);
-    d->webview->setFocus();
 }
