@@ -34,8 +34,9 @@
 #include <QTimer>
 #include <QMessageBox>
 #include <QAbstractSocket>
-
+#include <QUrlQuery>
 #include <QDateTime>
+#include <QWebEngineView>
 
 using namespace KGAPI2;
 
@@ -105,7 +106,6 @@ AuthWidgetPrivate::AuthWidgetPrivate(AuthWidget *parent):
     progress(AuthWidget::None),
     q(parent)
 {
-    setupUi();
 }
 
 AuthWidgetPrivate::~AuthWidgetPrivate()
@@ -174,6 +174,26 @@ void AuthWidgetPrivate::setupUi()
     connect(webview, &QWebEngineView::loadFinished, this, &AuthWidgetPrivate::webviewFinished);
 }
 
+void AuthWidgetPrivate::setUrl(const QUrl &url)
+{
+    webview->setUrl(url);
+    webview->setFocus();
+}
+
+void AuthWidgetPrivate::setVisible(bool visible)
+{
+    sslIndicator->setVisible(visible);
+    urlEdit->setVisible(visible);
+    webview->setVisible(visible);
+    if (showProgressBar && visible) {
+        progressbar->setVisible(visible);
+    } else {
+        progressbar->setVisible(visible);
+    }
+}
+
+
+
 void AuthWidgetPrivate::setProgress(AuthWidget::Progress progress)
 {
     qCDebug(KGAPIDebug) << progress;
@@ -273,13 +293,13 @@ void AuthWidgetPrivate::socketReady()
     const QByteArray data = connection->readLine();
     connection->deleteLater();
     qCDebug(KGAPIDebug) << QStringLiteral("Got connection on socket");
-    webview->stop();
-
-    sslIndicator->setVisible(false);
-    urlEdit->setVisible(false);
-    webview->setVisible(false);
-    progressbar->setVisible(false);
-    label->setVisible(true);
+    if (webview) { // when running in tests we don't have webview or any other widgets
+        webview->stop();
+    }
+    setVisible(false);
+    if (label) {
+        label->setVisible(true);
+    }
 
     const auto line = data.split(' ');
     if (line.size() != 3 || line.at(0) != QByteArray("GET") || !line.at(2).startsWith(QByteArray("HTTP/1.1"))) {
@@ -290,7 +310,7 @@ void AuthWidgetPrivate::socketReady()
 
     //qCDebug(KGAPIRaw) << "Receiving data on socket: " << data;
     const QUrl url(QString::fromLatin1(line.at(1)));
-    const QUrlQuery query(url.query());
+    const QUrlQuery query(url);
     const QString code = query.queryItemValue(QStringLiteral("code"));
     if (code.isEmpty()) {
         const QString error = query.queryItemValue(QStringLiteral("error"));
