@@ -1,5 +1,5 @@
 /*
-    Copyright 2013  Dan Vratil <dan@progdan.cz>
+    Copyright (C) 2013 - 2018  Daniel Vrátil <dvratil@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,6 @@
 
 #include "debug.h"
 
-Q_LOGGING_CATEGORY(KGAPIDebug, "org.kde.kgapi")
-Q_LOGGING_CATEGORY(KGAPIRaw, "org.kde.kgapi.raw")
+Q_LOGGING_CATEGORY(KGAPIDebug, "org.kde.kgapi", QtInfoMsg)
+Q_LOGGING_CATEGORY(KGAPIRaw, "org.kde.kgapi.raw", QtInfoMsg)
 
