@@ -66,14 +66,14 @@ class KGAPITASKS_EXPORT TaskListCreateJob : public KGAPI2::CreateJob
     /**
      * @brief Destructor
      */
-    virtual ~TaskListCreateJob();
+    ~TaskListCreateJob() override;
 
   protected:
 
     /**
      * @brief KGAPI2::Job::start implementation
      */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
     /**
      * @brief KGAPI2::CreateJob::handleReplyWithItems implementation
@@ -82,7 +82,7 @@ class KGAPITASKS_EXPORT TaskListCreateJob : public KGAPI2::CreateJob
      * @param rawData
      */
     ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                             const QByteArray& rawData) Q_DECL_OVERRIDE;
+                                             const QByteArray& rawData) override;
 
   private:
     class Private;
